SocialForceParams

Struct SocialForceParams 

pub struct SocialForceParams {
    pub tau: f64,
    pub a_social: f64,
    pub b_social: f64,
    pub k_body: f64,
    pub kappa_friction: f64,
    pub a_wall: f64,
    pub b_wall: f64,
    pub k_wall: f64,
    pub kappa_wall: f64,
    pub max_speed: f64,
    pub mass: f64,
}
Parameters for the Social Force Model with physical contact forces.

Default values are from Helbing, Farkas & Vicsek (2000) Table 1.

Fields

tau: f64

Relaxation time tau (seconds). Controls how quickly the agent adjusts its velocity toward the desired velocity. Smaller = more responsive.

a_social: f64

Social repulsion strength A (Newtons).

b_social: f64

Social repulsion range B (meters). The exponential decay length.

k_body: f64

Body compression coefficient k (kg/s^2). Activated on physical overlap.

kappa_friction: f64

Sliding friction coefficient kappa (kg/(m*s)). Tangential force on overlap.

a_wall: f64

Wall repulsion strength A_wall (Newtons).

b_wall: f64

Wall repulsion range B_wall (meters).

k_wall: f64

Wall body compression coefficient (kg/s^2).

kappa_wall: f64

Wall sliding friction coefficient (kg/(m*s)).

max_speed: f64

Maximum allowed speed (m/s). Integration clamps speed to this value.

mass: f64

Agent mass (kg). Used internally to convert the Helbing-calibrated Newton-scale coefficients (a_social, k_body, kappa_friction, a_wall, k_wall, kappa_wall) into accelerations (m/s²) so that the unit contract of this module (see module docs) holds.

Default: 80 kg, the value used by Helbing, Farkas & Vicsek (2000).