Deferred actions and the step context passed to agent step functions.
During an agent step, the agent holds a mutable borrow. Direct mutation
of the agent store (adding/removing agents) would conflict with this
borrow. Instead, step functions enqueue DeferredActions via the
StepContext, which are applied after the current agent’s step completes.
Structs
- Step
Context - Safe context passed to agent step functions.
Enums
- Deferred
Action - An action to apply after the current agent step completes.